=======================
``psyclone.tests.core``
=======================

.. automodule:: psyclone.tests.core

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.tests.core.access_info_test
   psyclone.tests.core.access_type_test
   psyclone.tests.core.component_indices_test
   psyclone.tests.core.signature_test
   psyclone.tests.core.symbolic_maths_test

.. currentmodule:: psyclone.tests.core
